@@ -1,15 +1,15 @@
 ####################################################################
 #' Download MP3 from URL
-#' 
-#' This function downloads YouTube videos or Soundcloud or any other 
-#' platform supported by the youtube-dl library, and converts them into 
-#' high quality MP3 files. The URL can be for a single video or a whole 
+#'
+#' This function downloads YouTube videos or Soundcloud or any other
+#' platform supported by the youtube-dl library, and converts them into
+#' high quality MP3 files. The URL can be for a single video or a whole
 #' playlist. It also returns metadata into an (invisible) list.
-#' 
+#'
 #' @section youtube-dl:
-#' More info from the original developers and its code: 
+#' More info from the original developers and its code:
 #' \href{https://github.com/ytdl-org/youtube-dl/}{youtube-dl's Github}
-#' 
+#'
 #' @family Scrapper
 #' @family Audio
 #' @param id Character. YouTube URL or ID to search for.
@@ -22,60 +22,71 @@
 #' @param cover Boolean. Google Search its squared cover?
 #' @param quiet Boolean. Keep quiet? If not, print messages.
 #' @return (Invisible) list with id's meta-data.
-#' @examples 
+#' @examples
 #' # You must have "youtube-dl" installed in your OS:
 #' \dontrun{
-#'  # Download video from YouTube and convert to MP3
-#'  get_mp3("https://www.youtube.com/watch?v=lrlKcCdVw9Q")
-#'  # OR simply
-#'  get_mp3("lrlKcCdVw9Q")
+#' # Download video from YouTube and convert to MP3
+#' get_mp3("https://www.youtube.com/watch?v=lrlKcCdVw9Q")
+#' # OR simply
+#' get_mp3("lrlKcCdVw9Q")
 #' }
 #' @export
-get_mp3 <- function(id, 
-                    mp3 = TRUE, 
-                    params = "", 
+get_mp3 <- function(id,
+                    mp3 = TRUE,
+                    params = "",
                     start_time = 0,
                     end_time = NA,
                     overwrite = TRUE,
                     info = TRUE,
                     cover = FALSE,
                     quiet = FALSE) {
-  
+
   # Build query's parameters
   query <- "--rm-cache-dir"
-  if (mp3)
-    query <- c(query, 
-               "-f bestaudio",
-               "--extract-audio",
-               "--audio-format mp3",
-               "--audio-quality 0")
-  if (info) query <- c(query, '--write-info-json')
+  if (mp3) {
+    query <- c(
+      query,
+      "-f bestaudio",
+      "--extract-audio",
+      "--audio-format mp3",
+      "--audio-quality 0"
+    )
+  }
+  if (info) query <- c(query, "--write-info-json")
   query <- c(query, '-o "%(title)s.%(ext)s"', params)
   query <- v2t(c("youtube-dl", query, id), quotes = FALSE, sep = " ")
   if (!quiet) message(v2t(c("Query:", query), quotes = FALSE, sep = " "))
-  
-  # Run youtube-dl  
-  tryCatch({
-    
-    system(query)
-    
-  }, error = function(err) {
-    msg <- "Something went wrong. Do you have youtube-dl installed?"
-    if (grepl("^darwin", R.version$os))
-      msg <- paste(msg, "Run in Terminal: brew install youtube-dl",
-                   "Then restart and try again", sep = "\n")
-    msg <- paste(msg, "If already installed, try updating it with:",
-                 "sudo pip3 install --upgrade youtube_dl", sep = "\n")
-    stop(msg)
-  })
-  
+
+  # Run youtube-dl
+  tryCatch(
+    {
+      system(query)
+    },
+    error = function(err) {
+      msg <- "Something went wrong. Do you have youtube-dl installed?"
+      if (grepl("^darwin", R.version$os)) {
+        msg <- paste(msg, "Run in Terminal: brew install youtube-dl",
+          "Then restart and try again",
+          sep = "\n"
+        )
+      }
+      msg <- paste(msg, "If already installed, try updating it with:",
+        "sudo pip3 install --upgrade youtube_dl",
+        sep = "\n"
+      )
+      stop(msg)
+    }
+  )
+
   f <- listfiles(getwd(), recursive = FALSE) %>%
     filter(grepl("\\.info\\.json", .data$filename)) %>%
-    arrange(desc(.data$mtime)) %>% .[1,1]
+    arrange(desc(.data$mtime)) %>%
+    .[1, 1]
+
   infox <- jsonlite::read_json(f)
-  invisible(file.remove(f)) 
+  invisible(file.remove(f))
   infox[["formats"]] <- NULL
-  
+
   if (cover & mp3 & info) {
     aux <- gsub("\\.mp3", "", infox$title)
     aux <- gsub("lyrics|lyric|official|video", "", tolower(aux))
@@ -83,29 +94,28 @@ get_mp3 <- function(id,
     url <- glued("https://www.google.com/search?q={aux}&tbm=isch&tbs=iar%3As")
     browseURL(url)
   }
-  
+
   # TRIM START AND/OR END OF AUDIO FILE
   if (any(c(start_time > 0, !is.na(end_time)))) {
     file <- sprintf("%s.mp3", infox$title)
     message(">>> Trimming audio file: ", file)
     trim_mp3(file,
-             start_time = start_time,
-             end_time = end_time,
-             overwrite = overwrite,
-             quiet = quiet)
+      start_time = start_time,
+      end_time = end_time,
+      overwrite = overwrite,
+      quiet = quiet
+    )
   }
-  
   return(invisible(infox))
-  
 }
 
 
 ####################################################################
 #' Trim MP3 Audio File
-#' 
-#' This function trims MP3 files given a start and/or end numeric 
+#'
+#' This function trims MP3 files given a start and/or end numeric
 #' timestamp. Requires \code{ffmpeg} installed in your machine.
-#' 
+#'
 #' @family Audio
 #' @inheritParams get_mp3
 #' @param file Character. File name to trim.
@@ -122,10 +132,12 @@ trim_mp3 <- function(file, start_time = 0, end_time = NA,
       message(paste("File", file, "does not exist or can't be found."))
       next
     }
-    query2 <- paste("ffmpeg -hide_banner -loglevel panic -y", 
-                    start, end, "-i",
-                    sprintf("'%s'", file), 
-                    sprintf("'%s'", paste0(file_name(file), "_trimmed.mp3")))
+    query2 <- paste(
+      "ffmpeg -hide_banner -loglevel panic -y",
+      start, end, "-i",
+      sprintf("'%s'", file),
+      sprintf("'%s'", paste0(file_name(file), "_trimmed.mp3"))
+    )
     if (!quiet) message("Query: ", query2)
     system(query2)
     if (overwrite) file.remove(gsub("_trimmed", "", file))
