@@ -2,7 +2,7 @@
 #' PostgreSQL Queries on Database (Read)
 #'
 #' This function lets the user query a PostgreSQL database. Previously
-#' was called \code{queryDummy} but was replaced and deprecated for a 
+#' was called \code{queryDummy} but was replaced and deprecated for a
 #' more general function by using the \code{from} parameter.
 #'
 #' @family Credentials
@@ -13,14 +13,15 @@
 #' @return data.frame. Result of fetching the \code{query} data.
 #' @export
 queryDB <- function(query, from, creds = NA) {
-
   try_require("RPostgreSQL")
   tic(id = "queryDummy")
 
   dw <- get_credentials(from = from, dir = creds)
   drv <- PostgreSQL()
-  con <- dbConnect(drv, host = dw$server, dbname = dw$database,
-                   port = dw$port, user = dw$uid, password = dw$pwd)
+  con <- dbConnect(drv,
+    host = dw$server, dbname = dw$database,
+    port = dw$port, user = dw$uid, password = dw$pwd
+  )
 
   q <- dbSendQuery(con, query)
   q <- fetch(q, n = -1)
